@@ -12,14 +12,14 @@ use warnings;
 
 use Carp;
 use Digest::MD5;
-use Storable;
 
 use Devel::Cover::DB;
+use Devel::Cover::DB::IO        0.75;
 
 # For comprehensive debug logging.
 use constant DEBUG => 0;
 
-our $VERSION = "0.74";
+our $VERSION = "0.75";
 our $AUTOLOAD;
 
 sub new
@@ -287,7 +287,8 @@ sub write
         # TODO - determine if Structure has changed to save writing it.
         # my $f = $df; my $n = 1; $df = $f . "." . $n++ while -e $df;
         # print STDERR "Writing [$file] to [$df]\n";
-        Storable::nstore($self->{f}{$file}, $df_temp); # unless -e $df;
+        my $io = Devel::Cover::DB::IO->new;
+        $io->write($self->{f}{$file}, $df_temp); # unless -e $df;
         unless (rename $df_temp, $df_final) {
             unless ($Devel::Cover::Silent) {
                 if(-e $df_final) {
@@ -316,7 +317,8 @@ sub read
     my $self     = shift;
     my ($digest) = @_;
     my $file     = "$self->{base}/structure/$digest";
-    my $s = eval { retrieve($file) };
+    my $io       = Devel::Cover::DB::IO->new;
+    my $s        = eval { $io->read($file) };
     if ($@ or !$s) {
         $self->debuglog("read retrieve $file failed: $@") if DEBUG;
         die $@;
@@ -400,7 +402,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.74 - 16th April 2011
+Version 0.75 - 17th April 2011
 
 =head1 LICENCE
 
